# Snakemake Rich Logger Plugin

Proof of concept logger plugin that uses [rich](https://github.com/Textualize/rich) for terminal styling and progress bar. 

Log formatting still needs lots of work but the progress bar works well.